@@ -13,12 +13,14 @@ local clean_task, gen_distress, gen_distress_attacked, handle_messages, lead_fle
 --
 -- These variables can be used to adjust the generic AI to suit other roles.
 --]]
+mem.rand          = 0 -- Random number from current think tick
 mem.atk_changetarget = 2 -- Distance at which target changes
 mem.atk_approach  = 1.4 -- Distance that marks approach
 mem.atk_aim       = 1.0 -- Distance that marks aim
 mem.atk_board     = false -- Whether or not to board the target
 mem.atk_kill      = true -- Whether or not to finish off the target
 mem.atk_minammo   = 0.1 -- Percent of ammo necessary to do ranged attacks
+mem.atk_skill     = 1.0 -- How skilled the pilot is when attacking. 1 is max, 0 is horrible
 mem.vulnattack    = 1.5 -- Vulnerability threshold
 mem.ranged_ammo   = 0 -- How much ammo is left, we initialize to 0 here just in case
 mem.recharge      = false --whether to hold off shooting to avoid running dry of energy
@@ -31,7 +33,6 @@ mem.aggressive    = false -- Should pilot actively attack enemies?
 mem.defensive     = true -- Should pilot defend itself
 mem.whiteknight   = false -- Should the AI help out independent ships duking it out?
 mem.cooldown      = false -- Whether the pilot is currently cooling down.
-mem.heatthreshold = 0.5 -- Weapon heat to enter cooldown at [0-2 or nil]
 mem.safe_distance = 8000 -- Safe distance from enemies to stop running away
 mem.safe_jump_distance = 300 -- Safe distance from enemies to jump
 mem.land_planet   = true -- Should land on planets?
@@ -55,6 +56,7 @@ mem.leadermaxdist = nil -- Distance from leader to run back to leader
 mem.gather_range  = 800 -- Radius in which the pilot looks for gatherables
 mem.lanes_useneutral = false -- Whether or not to use neutral lanes
 mem.uselanes       = true -- Try to use lanes
+mem.loiter_compensate_vel = true -- Try to compensate velocity when loitering
 
 --[[Control parameters: mem.radius and mem.angle are the polar coordinates
 of the point the pilot has to follow when using follow_accurate.
@@ -100,6 +102,9 @@ local stateinfo = {
       attack   = true,
       noattack = true,
    },
+   inspect_attacker = {
+      fighting = true,
+   },
    return_lane = {
       running  = true,
       noattack = true,
@@ -114,6 +119,21 @@ local stateinfo = {
       fighting = true,
       noattack = true,
    },
+   runaway_land = {
+      running  = true,
+      fighting = true,
+      noattack = true,
+   },
+   runaway_jump = {
+      running  = true,
+      fighting = true,
+      noattack = true,
+   },
+   runaway_nojump = {
+      running  = true,
+      fighting = true,
+      noattack = true,
+   },
    refuel = {
       noattack = true,
    },
@@ -189,6 +209,7 @@ end
 
 -- Run instead of "control" when under manual control; use should be limited
 function control_manual( dt )
+   mem.rand = rnd.rnd()
    mem.elapsed = mem.elapsed + dt
    local p = ai.pilot()
    local task = ai.taskname()
@@ -210,21 +231,25 @@ local function sameFleet( pa, pb )
    return la == lb
 end
 
+-- Try to explore what happened if interested
+local function msg_explore( _p, si, dopush, sender, data )
+   if not dopush or sender==nil or not data or not data:exists() then return false end
+   local ap = data:pos()
+   if should_investigate( ap, si ) then
+      ap = ap + vec2.newP( 500*rnd.rnd(), rnd.angle () )
+      ai.pushtask("inspect_moveto", ap )
+      return true
+   end
+   return false
+end
+
 --[[
 Functions to handle different commands that can be received
 --]]
 local message_handler_funcs = {
    -- Case message is being sent from the environment, such as asteroids
-   asteroid = function( _p, si, dopush, sender, data )
-      if not dopush or sender==nil or not data or not data:exists() then return false end
-      local ap = data:pos()
-      if should_investigate( ap, si ) then
-         ap = ap + vec2.newP( 500*rnd.rnd(), rnd.angle () )
-         ai.pushtask("inspect_moveto", ap )
-         return true
-      end
-      return false
-   end,
+   asteroid = msg_explore, -- TODO maybe we don't need to distinguish asteroid vs explosion?
+   explosion = msg_explore,
    distress = function( _p, _si, _dopush, sender, data )
       if sender==nil then return false end
       return distress_handler( sender, data )
@@ -252,7 +277,7 @@ local message_handler_funcs = {
    end,
    -- Follower is being attacked
    f_attacked = function( p, si, dopush, sender, data )
-      if sender==nil or not sender:exists() or sender:leader()~=p then return false end
+      if mem.ignoreorders or sender==nil or not sender:exists() or sender:leader()~=p then return false end
       if data and data:exists() then
          ai.hostile( data ) -- Set hostile
          -- Also signal to other followers
@@ -276,8 +301,9 @@ local message_handler_funcs = {
       mem.form_pos = data
       return false
    end,
+   -- Leader is being attacked
    l_attacked = function( p, si, dopush, sender, data )
-      if not dopush or sender==nil or not sender:exists() or sender~=p:leader() then return false end
+      if mem.ignoreorders or not dopush or sender==nil or not sender:exists() or sender~=p:leader() then return false end
       if data and data:exists() then
          ai.hostile( data ) -- Set hostile
          if not si.fighting and should_attack( data, si, true ) then
@@ -287,6 +313,14 @@ local message_handler_funcs = {
       end
       return false
    end,
+   l_investigate = function( p, si, dopush, sender, data )
+      if mem.ignoreorders or not dopush or sender==nil or not sender:exists() or sender~=p:leader() then return false end
+      if not si.fighting then -- inspect_attacker is fighting, so it shouldn't duplicate
+         ai.pushtask("inspect_attacker", data)
+         return true
+      end
+      return false
+   end,
    hyperspace_abort = function( p, _si, _dopush, sender, _data )
       if sender==nil or not sender:exists() or sender~=p:leader() then return false end
       if ai.taskname()=="hyperspace_follow" then
@@ -299,9 +333,9 @@ local message_handler_funcs = {
    e_attack = function( p, _si, dopush, sender, data )
       local l = p:leader()
       if mem.ignoreorders or not dopush or sender==nil or not sender:exists() or sender~=l or data==nil or not data:exists() or data:leader() == l then return false end
-      clean_task()
-      --if (si.attack and si.forced and ai.taskdata()==data) or data:flags("disabled") then
-      if data:flags("disabled") then
+      p:taskClear()
+      --if (si.attack and si.forced and ai.taskdata()==data) or data:disabled() then
+      if data:disabled() then
          ai.pushtask("attack_forced_kill", data)
       else
          ai.pushtask("attack_forced", data)
@@ -311,12 +345,14 @@ local message_handler_funcs = {
    e_hold = function( p, _si, dopush, sender, _data )
       local l = p:leader()
       if mem.ignoreorders or not dopush or sender==nil or not sender:exists() or sender~=l then return false end
+      p:taskClear()
       ai.pushtask("hold")
       return true
    end,
    e_return = function( p, _si, dopush, sender, _data )
       local l = p:leader()
       if mem.ignoreorders or not dopush or sender==nil or not sender:exists() or sender~=l then return false end
+      p:taskClear()
       ai.pushtask( "flyback", mem.carried )
       return true
    end,
@@ -329,8 +365,11 @@ local message_handler_funcs = {
    e_autonav = function( p, _si, dopush, sender, _data )
       local l = p:leader()
       if mem.ignoreorders or not dopush or sender==nil or not sender:exists() or sender~=l then return false end
-      ai.pushtask( "flyback", false )
-      return true
+      if ai.taskname() ~= "follow_fleet" then
+         p:taskClear()
+         ai.pushtask( "flyback", false )
+         return true
+      end
    end
 }
 
@@ -386,7 +425,7 @@ function should_attack( enemy, si, aggressor )
       local ltask, ldata = l:task()
       local lsi = _stateinfo( ltask )
       if lsi.fighting then
-         if ldata and ldata:exists() then
+         if ldata and ldata.exists and ldata:exists() then
             -- Check to see if the pilot group the leader is fighting is the
             -- same as the current enenmy
             if sameFleet( ldata, enemy ) then
@@ -406,7 +445,7 @@ function should_attack( enemy, si, aggressor )
 
    -- Check to see if we want to go back to the lanes
    local lr = mem.enemyclose
-   if mem.natural and lr then
+   if mem.natural and lr and not mem.guardpos then
       local d, _pos = lanes.getDistance2P( p, enemy:pos() )
       if math.huge > d and d > lr*lr then
          return false
@@ -429,7 +468,7 @@ end
 -- Whether or not the pilot should investigate a certain location.
 --]]
 function should_investigate( pos, si )
-   if si.fighting or si.forced or si.noattack or mem.carried or mem.leader() then
+   if si.fighting or si.forced or si.noattack or mem.carried or ai.pilot():leader() then
       return false
    end
 
@@ -438,7 +477,7 @@ function should_investigate( pos, si )
       return false
    end
 
-   -- Conmfort
+   -- Comfort
    local ec = mem.enemyclose or math.huge
    local ec2 = ec*ec
 
@@ -448,7 +487,7 @@ function should_investigate( pos, si )
    end
 
    -- Check to see if we want to go back to the lanes
-   if mem.natural and ec < math.huge then
+   if mem.natural and ec < math.huge and not mem.guardpos then
       local d, _pos = lanes.getDistance2P( ai.pilot(), pos )
       if math.huge > d and d > ec2 then
          return false
@@ -485,8 +524,11 @@ function control_funcs.generic_attack( si, noretarget )
          (parmour < mem.armour_run
             and parmour < target_parmour ) then
       ai.pushtask("runaway", target)
-
-   -- Think like normal
+   -- Carried fighters are a bit more jumpy
+   elseif mem.carried and parmour < mem.armour_run then
+      ai.pilot():taskClear()
+      ai.pushtask( "flyback", true )
+      return false
    else
       -- Cool down, if necessary.
       should_cooldown()
@@ -539,12 +581,32 @@ control_funcs.inspect_moveto = function ()
          end
       end
    end
-   if mem.natural and target and lr and lanes.getDistance2P( p, target ) > lr*lr then
+   if mem.natural and not mem.guardpos and target and lr and lanes.getDistance2P( p, target ) > lr*lr then
       ai.poptask()
       return false
    end
    return true
 end
+control_funcs.inspect_attacker = function ()
+   local p = ai.pilot()
+   local target = ai.taskdata()
+   if not target then return end
+
+   -- See if there is an enemy to attack
+   local enemy = atk.preferred_enemy( nil, true )
+   if should_attack( enemy, nil, false ) then
+      ai.hostile(enemy) -- Should be done before taunting
+      consider_taunt(enemy, true)
+      ai.poptask()
+      ai.pushtask("attack", enemy)
+      return false
+   end
+
+   for k,v in ipairs(p:followers()) do
+      p:msg( v, "l_investigate", target + vec2.newP(500*rnd.rnd(), rnd.angle()) )
+   end
+   return true
+end
 function control_funcs.runaway ()
    local p = ai.pilot()
    if mem.norun or p:leader() ~= nil then
@@ -608,6 +670,7 @@ function control_funcs.attack_forced ()
 end
 function control_funcs.flyback () return true end
 function control_funcs.hold () return true end
+control_funcs.scan = scans.control_funcs
 function attacked_manual( attacker )
    local p = ai.pilot()
    -- Ignore hits from dead or stealthed pilots.
@@ -653,7 +716,7 @@ end
 function attacked( attacker )
    local p = ai.pilot()
    -- Ignore hits from dead pilots.
-   if not attacker:exists() or not p:inrange( attacker ) then
+   if not attacker:exists() then
       return
    end
 
@@ -688,6 +751,31 @@ function attacked( attacker )
       end
    end
 
+   -- See if should investigate
+   if not p:inrange( attacker ) then
+      -- TODO ideally not use the _current_ attacker position, but something
+      -- related to where the weapon was fired from
+      local ap = attacker:pos()
+      -- Don't use should_investigate here, because it needs to be more aggressive
+      if not si.fighting or si.forced or si.noattack then
+         local d = ap:dist( p:pos() )
+         local fuzz = math.max(500, d*0.5)
+         local target = ap + vec2.newP( fuzz*rnd.rnd(), rnd.angle () )
+         ai.pushtask("inspect_attacker", target )
+
+         -- So this is a corner case with friendly factions not breaking stealth or messing with the player
+         local wp = attacker:withPlayer()
+         for k,v in ipairs(p:followers()) do
+            p:msg( v, "l_investigate", ap + vec2.newP(fuzz*rnd.rnd(), rnd.angle()) )
+            if wp then
+               v:setHostile(true)
+            end
+         end
+         return true
+      end
+      return
+   end
+
    -- Notify followers that we've been attacked
    if not si.fighting then
       for k,v in ipairs(p:followers()) do
@@ -736,6 +824,7 @@ end
 
 -- Required "control" function
 function control( dt )
+   mem.rand = rnd.rnd()
    mem.elapsed = mem.elapsed + dt
    local p = ai.pilot()
 
@@ -800,6 +889,15 @@ function control( dt )
       return
    end
 
+   -- See if we have to fly back due to low health
+   if mem.carried then
+      if p:armour() < mem.armour_run then
+         p:taskClear()
+         ai.pushtask( "flyback", true )
+         return
+      end
+   end
+
    -- Cooldown completes silently.
    if mem.cooldown then
       mem.tickssincecooldown = 0
@@ -821,21 +919,11 @@ function control( dt )
          -- Cooldown preempts everything we haven't explicitly checked for.
          if mem.cooldown then
             return
-         -- If the ship is hot, consider cooling down.
-         elseif p:temp() > 300 then
-            -- Ship is quite hot, better cool down.
-            if p:temp() > 400 then
-               mem.cooldown = true
-               p:setCooldown(true)
-               return
-            -- Cool down if the current weapon set is suffering from >= 20% accuracy loss.
-            -- This equates to a temperature of 560K presently.
-            -- Focus on primaries
-            elseif (p:weapsetHeat(1) > 0.2) then
-               mem.cooldown = true
-               p:setCooldown(true)
-               return
-            end
+         -- Reload if necessary
+         elseif atk.seekers_ammo() <= 0.3 then
+            mem.cooldown = true
+            p:setCooldown(true)
+            return
          end
       end
 
@@ -857,6 +945,9 @@ function control( dt )
          local dist = ai.dist( l )
          if lmd < dist then
             if task ~= "flyback" then
+               if mem.carried then
+                  p:taskClear()
+               end
                ai.pushtask("flyback", false)
             end
             return
@@ -865,7 +956,7 @@ function control( dt )
    end
 
    -- Check to see if we want to go back to the lanes
-   if mem.natural and si.fighting and not si.running then
+   if mem.natural and si.fighting and not si.running and not mem.guardpos then
       local lr = mem.enemyclose
       if lr then
          local d, pos = lanes.getDistance2P( p, p:pos() )
@@ -931,6 +1022,8 @@ function create_pre ()
    mem.jumpedin   = p:flags("jumpingin")
    mem.carried    = p:flags("carried")
    mem.mothership = p:mothership()
+   --mem.creation_outfit is set when created automagically and points to the
+   --outfit that created the pilot (if launched from a  fighter bay)
 
    -- Amount of faction lost when the pilot distresses at the player, is modulated later
    mem.distress_hit = p:points()
@@ -945,7 +1038,7 @@ function create_pre ()
          p:setFuel( true ) -- Full fuel
       else
          local f = (rnd.twosigma()/4 + 0.5)*(ps.fuel_max-ps.fuel_consumption)
-         f = f + ps.fuel_consumption
+         f = math.max( f, 0 ) + ps.fuel_consumption
          p:setFuel( f )
       end
    end
@@ -958,11 +1051,12 @@ end
 
 -- Finishes create stuff like choose attack and prepare plans
 function create_post ()
+   mem.rand       = rnd.rnd()
    mem.scanned    = {} -- must create for each pilot
 
    -- Give a small delay... except for escorts?
    if mem.jumpedin and not mem.carried then
-      ai.settimer( 0, rnd.uniform(5.0, 6.0) )
+      ai.settimer( 0, rnd.uniform(5, 6) )
       ai.pushtask("jumpin_wait")
    end
 
@@ -970,6 +1064,13 @@ function create_post ()
    if mem.carried then
       mem.distress_hit = 0.
    end
+
+   -- Process skill
+   if mem.atk_skill < 1 then
+      local p = ai.pilot()
+      -- We assume this is run before anything else, so we replace
+      p:intrinsicSet( "ew_track", -(1-mem.atk_skill) * 80, true )
+   end
 end
 
 -- Set transport ship parameters
@@ -985,18 +1086,29 @@ function transportParam ( price )
 end
 
 -- taunts
-function taunt( _target, _offensive )
-   -- Empty stub
+function taunt( target, offensive )
+   -- Taunts if applicable
+   if mem.taunt then
+      -- PERS just use strings
+      if type(mem.taunt)=="string" then
+         return mem.taunt
+      end
+      return mem.taunt( target, offensive )
+   end
 end
 
 -- Lower taunt frequency, at most once per X seconds per target
 mem._taunted = {}
 function consider_taunt( target, offensive )
    if mem.carried then return end -- Fighters don't taunt
-   local id = target:id()
+   local rtarget = target:leader() or target -- Always consider leader
+   local id = rtarget:id()
    local last_taunted = mem._taunted[id] or -100
    if mem.elapsed - last_taunted > 15 then
-      taunt( target, offensive )
+      local msg = taunt( rtarget, offensive )
+      if msg then
+         ai.pilot():comm( rtarget, msg )
+      end
       mem._taunted[id] = mem.elapsed
    end
 end
@@ -1012,10 +1124,15 @@ function distress_handler( pilot, attacker )
    -- Make sure pilot is setting their target properly
    if pilot == attacker then return end
 
-   -- Ignore please of help when bribed by the attacker
+   -- Ignore pleads of help when bribed by the attacker
    if ai.isbribed(attacker) then return end
 
+   -- Ignore distress calls from the player
+   if pilot:withPlayer() then return end
+
    local p       = ai.pilot()
+   -- Player's faction ignores distress calls
+   if p:withPlayer() then return end
    local pfact   = pilot:faction()
    local afact   = attacker:faction()
    local aifact  = p:faction()
@@ -1030,7 +1147,7 @@ function distress_handler( pilot, attacker )
    --[[
    Who is the badguy table. Columns refer to attacker, rows to pilot being attacked.
 
-                    attacker
+                  attacker
    pilot     ally    neutral      enemy           player
             ------------------------------------------
    ally      nil     attacker     attacker        attacker
@@ -1053,8 +1170,8 @@ function distress_handler( pilot, attacker )
          end
       else -- neutral
          if mem.whiteknight then
-            local p_m = pilot:memory()
-            if p_m.natural and not aifact:areNeutral(pfact) then
+            -- Only whiteknight with natural pilots
+            if pilot:memory().natural and p:memory().natural and not aifact:areNeutral(pfact) then
                badguy = attacker
             end
          end
@@ -1101,7 +1218,7 @@ function distress_handler( pilot, attacker )
             return true
          end
       end
-   -- If not fleeing or refueling, begin attacking
+   -- If not fleeing or refuelling, begin attacking
    elseif task ~= "runaway" and task ~= "refuel" then
       if not si.noattack and mem.aggressive then
          -- Ignore if not interested in attacking
@@ -1169,21 +1286,15 @@ function gen_distress_attacked( attacker )
    mem.distressed = 1
 end
 
--- Puts the pilot into cooldown mode if its weapons are overly hot and its shields are relatively high.
--- This can happen during combat, so mem.heatthreshold should be quite high.
+-- Puts the pilot into cooldown mode if necessary.
 function should_cooldown()
    local p = ai.pilot()
-   local mean = p:weapsetHeat(1) -- Care about primaries
-   local _, pshield = p:health()
 
    -- Don't want to cool down again so soon.
    -- By default, 15 ticks will be 30 seconds.
    if mem.tickssincecooldown < 15 then
       return
-   -- The weapons are extremely hot and cooldown should be triggered.
-   -- This did not work before. However now it causes ships to just stop dead and wait for energy regen.
-   -- Not sure this is better...
-   elseif mean > mem.heatthreshold and pshield > 50 then
+   elseif atk.seekers_ammo() <= 0.0 then
       mem.cooldown = true
       p:setCooldown(true)
    end
