@@ -1,2 +1,2 @@
 local nebu_img = require "bkg.lib.nebula_image"
-nebu_img.init( "messier.webp" )
+nebu_img.init( "messier" )
