@@ -1,5 +1,4 @@
 function add( p )
-   p:setInvincible(true)
    p:setInvisible(true)
 end
 
@@ -7,7 +6,6 @@ function remove( p )
    if player.pilot()~=p then -- and p:exists() then
       p:rm()
    else
-      p:setInvincible(false)
       p:setInvisible(false)
    end
 end
