@@ -1,14 +1,14 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Strafer's Ceremony">
- <trigger>enter</trigger>
+ <location>enter</location>
  <chance>50</chance>
  <cond>
-  system.cur():faction() == faction.get("Dvaered") and
-  player.misnDone("Dvaered Meeting") and
-  var.peek("invasion_time") and
-  not (player.misnDone("Dvaered Ballet") or player.misnActive("Dvaered Ballet")) and
-  not (system.cur() == system.get("Dvaer"))
+   system.cur():faction() == faction.get("Dvaered") and
+   player.misnDone("Dvaered Meeting") and
+   var.peek("invasion_time") and
+   not (player.misnDone("Dvaered Ballet") or player.misnActive("Dvaered Ballet")) and
+   not (system.cur() == system.get("Dvaer"))
  </cond>
  <notes>
   <done_misn name="Dvaered Meeting"/>
@@ -21,11 +21,10 @@
 --]]
 
 local timer
--- luacheck: globals finish msgme (Hook functions passed by name)
 
 function create ()
    local invasion_time = var.peek("invasion_time")
-   if time.get() < time.fromnumber(invasion_time) + time.create(0, 10, 0) then
+   if time.get() < time.fromnumber(invasion_time) + time.new(0, 10, 0) then
       evt.finish()
    end
 
