@@ -391,6 +391,13 @@ function create ()
       updater0130( did0120, did0110, did0100, did090 )
       didupdate = true
    end
+   -- Small bug fixed in 0.13.2 requires updating
+   if not save_version or naev.versionTest( save_version, "<0.13.2") then
+      -- Bug that cleared FLF known state
+      if var.peek("disc_frontier") then
+         fcts.setKnown( faction.get("FLF"), true )
+      end
+   end
 
    -- Note that games before 0.10.0 will have lastplayed set days from the unix epoch
    local nc = naev.cache()
