@@ -30,7 +30,7 @@ success_text = {
 }
 
 pay_text = {
-   _([[As you dock the station, Benito approaches you with a smile. "Thank you for your help," she says. "The mission was a resounding success! What we've accomplished will greatly help our efforts against the Dvaereds in the future." She hands you a credit chip. "That's your payment. Until next time!" Benito sees herself out as a number of additional FLF soldiers congratulate you. It occurs to you that you never learned what the mission actually was. Perhaps you will find out some other time.]]),
+   _([[As you dock the station, Benito approaches you with a smile. "Thank you for your help," she says. "The mission was a resounding success! What we've accomplished will greatly help our efforts against the Dvaered in the future." She hands you a credit chip. "That's your payment. Until next time!" Benito sees herself out as a number of additional FLF soldiers congratulate you. It occurs to you that you never learned what the mission actually was. Perhaps you will find out some other time.]]),
 }
 
 function create ()
@@ -41,13 +41,13 @@ function create ()
    mem.credits = 250e3
    mem.reputation = 2
 
-   misn.setNPC( _("Benito"), "flf/unique/benito.webp", _("Benito seems to want to speak with you.") )
+   misn.setNPC( _("Benito"), "flf/unique/benito", _("Benito seems to want to speak with you.") )
 end
 
 
 function accept ()
-   if tk.yesno( _("Taking One for the Team"), fmt.f(_([[Benito smiles as you approach her. "Hello again, {player}!" she says. "I have another mission for you, should you choose to accept it. See, we have... an important covert operation we need to launch in Raelid. I won't bore you with the details of that operation, but I need someone to distract the Dvaered forces while we do this. You'll basically need to travel to the {sys} system and wreak havoc there so that the Dvaereds go after you and not the soldiers conducting the operation.
-    "Of course, this will be a highly dangerous mission, and I can't guarantee any backup for you. You will be paid substantially, however, and this will surely earn you more respect among our ranks. Would you be interested?"]]), {player=player.name(), sys=mem.missys} ) ) then
+   if tk.yesno( _("Taking One for the Team"), fmt.f(_([[Benito smiles as you approach her. "Hello again, {player}!" she says. "I have another mission for you, should you choose to accept it. See, we have... an important covert operation we need to launch in Raelid. I won't bore you with the details of that operation, but I need someone to distract the Dvaered forces while we do this. You'll basically need to travel to the {sys} system and wreak havoc there so that the Dvaered go after you and not the soldiers conducting the operation.
+   "Of course, this will be a highly dangerous mission, and I can't guarantee any backup for you. You will be paid substantially, however, and this will surely earn you more respect among our ranks. Would you be interested?"]]), {player=player.name(), sys=mem.missys} ) ) then
       tk.msg( _("Taking One for the Team"), _([["Great! The team in charge of the operation will be hiding out around Raelid until they get an opening from your efforts. I will message you when they succeed. Good luck, and try not to get yourself killed!" She grins, and you grin back. Now to cause some mayhem...]]) )
 
       misn.accept()
@@ -77,7 +77,7 @@ function land ()
       player.pay( mem.credits )
       flf.setReputation( 30 )
       faction.get("FLF"):hit( mem.reputation )
-      flf.addLog( _([[You helped the FLF conduct some kind of operation in Raelid by distracting the Dvaereds in another system.]]) )
+      flf.addLog( _([[You helped the FLF conduct some kind of operation in Raelid by distracting the Dvaered in another system.]]) )
       misn.finish( true )
    end
 end
