@@ -1,15 +1,11 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Kex's Freedom 4">
- <flags>
-  <unique />
- </flags>
- <avail>
-  <location>Bar</location>
-  <chance>100</chance>
-  <planet>Minerva Station</planet>
-  <done>Kex's Freedom 3</done>
- </avail>
+ <unique />
+ <location>Bar</location>
+ <chance>100</chance>
+ <spob>Minerva Station</spob>
+ <done>Kex's Freedom 3</done>
  <notes>
   <campaign>Minerva</campaign>
  </notes>
@@ -18,14 +14,14 @@
 --[[
    Freeing Kex 4
 
-   Player has to go confront a guy in the frontier and is constantly harassed
+   Player has to go confront a guy in the Frontier and is constantly harassed
    by bounty hunters while active. Fairly straight forward with a pretty hard
    fight at the end.
 --]]
 local minerva  = require "common.minerva"
-local portrait = require 'portrait'
 local love_audio = require 'love.audio'
 local vn       = require 'vn'
+local vni      = require "vnimage"
 local equipopt = require 'equipopt'
 local reverb_preset = require 'reverb_preset'
 local fmt = require "format"
@@ -38,14 +34,11 @@ local lmisn = require "lmisn"
 --  2: return to kex
 mem.misn_state = nil
 local enemies, pjie, thug_leader, thug_pilots -- Non-persistent state
--- luacheck: globals enter generate_npc jie_board jie_death jie_epilogue jie_takeoff load_game thug_heartbeat (Hook functions passed by name)
--- luacheck: globals approach_jie approach_kex (NPC functions passed by name)
 
-local targetplanet, targetsys = planet.getS("Jorlan")
+local targetplanet, targetsys = spob.getS("Jorlan")
 
 -- TODO custom graphic?
-mem.jie_portrait = portrait.get()
-mem.jie_image = portrait.getFullPath(mem.jie_portrait)
+mem.jie_image, mem.jie_portrait = vni.generic()
 
 local money_reward = minerva.rewards.kex4
 
@@ -95,10 +88,10 @@ function generate_npc ()
       lmisn.fail(_("You were supposed to take care of Jie!"))
    end
 
-   if planet.cur() == planet.get("Minerva Station") then
+   if spob.cur() == spob.get("Minerva Station") then
       misn.npcAdd( "approach_kex", minerva.kex.name, minerva.kex.portrait, minerva.kex.description )
 
-   elseif mem.misn_state==0 and planet.cur() == targetplanet then
+   elseif mem.misn_state==0 and spob.cur() == targetplanet then
       misn.npcAdd( "approach_jie", _("Jie de Luca"), mem.jie_portrait, _("You see an individual matching the description of Jie de Luca.") )
 
    end
@@ -154,7 +147,7 @@ He gives a sort of half-hearted grin and disappears into the shadows.]]))
 He seems at a loss of words.
 "You know…"]]))
       vn.menu{
-         { _([["What?"]]), "intro2" },
+         { p_("you to Kex", [["What?"]]), "intro2" },
          { _("…"), "intro2" },
       }
       vn.label("intro2")
@@ -163,7 +156,7 @@ He seems at a loss of words.
       kex(_([[Before you can speak, he keeps on going.
 "Anyway, don't let my silly thoughts bother you. Let us get back to topic."
 His eyes don't seem to have changed.]]))
-      kex(_([["So I was putting together the pieces and found a close collaborator of the CEO, someone called Jie de Luca who seems to be situated in the frontier. They seem to go fairly far back with the CEO and probably have more information. As this is our best lead for now, I hate to ask this of you, but would you be able to check them out and see if we can get some more information?"]]))
+      kex(_([["So I was putting together the pieces and found a close collaborator of the CEO, someone called Jie de Luca who seems to be situated in the Frontier. They seem to go fairly far back with the CEO and probably have more information. As this is our best lead for now, I hate to ask this of you, but would you be able to check them out and see if we can get some more information?"]]))
       vn.menu{
          { _("Accept"), "accept" },
          { _("Decline"), "decline" },
@@ -291,7 +284,7 @@ function enter ()
       local fbh = faction.dynAdd( "Mercenary", "kex_bountyhunter", _("Bounty Hunter"), {ai="mercenary"} )
       thug_pilots = {}
       for k,v in ipairs(thugs) do
-         local ppos = pos + vec2.new( rnd.rnd()*200, rnd.rnd()*360 )
+         local ppos = pos + vec2.newP( rnd.rnd()*200, rnd.angle() )
          local p = pilot.add( v, fbh, ppos, nil, {naked=true} )
          equipopt.pirate( p )
          if not thug_leader then
@@ -320,9 +313,9 @@ function enter ()
       hook.timer( 5, "thug_heartbeat" )
 
    elseif mem.misn_state~=1 and rnd.rnd() < mem.thug_chance then
-      -- Make sure system isn't claimed, but we don't claim it
-      if misn.claim( system.cur(), true ) then
-         -- Spawn near the center, they home in on player
+      -- Make sure system isn't claimed, but we don't claim it (inclusive test)
+      if naev.claimTest( system.cur(), true ) then
+         -- Spawn near the centre, they home in on player
          spawn_thugs( vec2.newP(0.7*system.cur():radius()*rnd.rnd(), rnd.angle()), false )
          -- Timer
          hook.timer( 5, "thug_heartbeat" )
@@ -333,7 +326,7 @@ function enter ()
       pilot.clear()
       pilot.toggleSpawn(false)
 
-      local pos = targetplanet:pos() + vec2.new( 3000, rnd.rnd()*360 )
+      local pos = targetplanet:pos() + vec2.newP( 3000, rnd.angle() )
       pjie = pilot.add("Kestrel", "Independent", pos, _("Jie de Luca"), {naked=true, ai="baddie_norun"})
       equipopt.generic( pjie, nil, "elite" )
       pjie:setHostile(true)
@@ -356,7 +349,7 @@ function enter ()
       end
       enemies = { pjie }
       for k,v in ipairs(henchmen) do
-         local ppos = pos + vec2.new( rnd.rnd()*200, rnd.rnd()*360 )
+         local ppos = pos + vec2.newP( rnd.rnd()*200, rnd.angle() )
          local p = pilot.add( v, "Independent", ppos, nil, {naked=true, ai="baddie_norun"} )
          equipopt.pirate( p )
          p:setLeader( pjie )
@@ -416,7 +409,7 @@ function thug_heartbeat ()
 end
 
 function jie_death ()
-   misn.markerMove( mem.misn_marker, planet.get("Minerva Station") )
+   misn.markerMove( mem.misn_marker, spob.get("Minerva Station") )
    misn.osdActive(2)
    mem.misn_state = 2
 
@@ -434,7 +427,7 @@ function jie_board ()
    vn.na(_("Slowly the chair turns to reveal Jie de Luca, holding their head from which blood is gushing out. In their other hand they clutch a weapon, but it doesn't really look like they are in any condition to use it."))
    cjie(_([["Feeling proud of yourself dog? Wagging your tail thinking about getting a prize from your master?"
 They cough and you can see some blood drip from the side of their mouth.]]))
-   vn.music( "snd/sounds/loops/alarm.ogg" ) -- blaring alarm
+   vn.music( "snd/sounds/loops/alarm" ) -- blaring alarm
    cjie(_([["This is why we can't have nice things…"
 As their head slouches down, you hear an alarm blaring, and a voice announcing "Self-destruct imminent!".]]))
    vn.na(_("You leave Jie behind as you rush to get back to your ship to get away from the explosion."))
