@@ -41,11 +41,11 @@ local reward = 50e3 -- Can get doubled, must be global!
 local reward_outfit = outfit.get("Love Letter")
 
 local npc_name = _("Old-Fashioned Man")
-local npc_portrait = "neutral/unique/michal.webp"
+local npc_portrait = "neutral/unique/michal"
 local npc_image = portrait.getFullPath( npc_portrait )
 
 local npc2_name = _("Young Woman")
-local npc2_portrait = "neutral/unique/paddy.webp"
+local npc2_portrait = "neutral/unique/paddy"
 local npc2_image = portrait.getFullPath( npc2_portrait )
 
 function create () --No system shall be claimed by mission
@@ -85,7 +85,9 @@ function accept ()
       vn.func( function ()
          mem.reward = mem.reward * 2 --look at you go, double the reward
       end )
-      michal(fmt.f(_([[The man grabs your arm as you begin to get up. "Alright, how about {credits}? Look, I wouldn't want The Empire reading these. The Emperor himself would blush." You sigh and give the man a long pause before answering.]]), {credits=fmt.credits(mem.reward)} ) )
+      michal(function ()
+         return fmt.f(_([[The man grabs your arm as you begin to get up. "Alright, how about {credits}? Look, I wouldn't want The Empire reading these. The Emperor himself would blush." You sigh and give the man a long pause before answering.]]), {credits=fmt.credits(mem.reward)} )
+      end )
       vn.menu{
          {_([[Yes]]), "2yes"},
          {_([[No]]), "decline"},
@@ -152,7 +154,7 @@ function land()
    vn.transition()
 
    paddy(fmt.f(_([[You deliver the letters to a young woman who excitedly takes them and thanks you profusely. It seems you really made her day. When you check your balance, you see that {credits} have been transferred into your account. It also seems like you forgot a letter in the ship, but there were enough that you don't think it will be missed.]]),
-      {credits=fmt.credits(mem.reward)}))
+      {credits="#g"..fmt.credits(mem.reward).."#0"}))
    vn.sfxVictory()
    vn.func( function ()
       player.pay( mem.reward )
