@@ -144,8 +144,17 @@ function create ()
 
    local systems = lmisn.getSysAtDistance( system.cur(), 1, 5,
       function(s)
-         local p = s:presences()[mem.target_faction:nameRaw()]
-         return p ~= nil and p > 0
+         local pres = s:presences()
+         -- Target faction must have presence in system
+         local p = pres[mem.target_faction:nameRaw()] or 0
+         if p <= 0 then
+            return false
+         end
+         -- Need some independent standing so the player can ask for hints and such
+         if (pres["Independent"] or 0) <= 0 then
+            return false
+         end
+         return true
       end )
 
    -- Create the table of system the player will visit now (to claim)
@@ -281,6 +290,7 @@ function enter ()
          target_ship:setHilight( true )
          target_ship:setVisplayer()
          target_ship:setHostile()
+         target_ship:memory().capturable = true
 
          mem.death_hook = hook.pilot( target_ship, "death", "target_death" )
          mem.board_hook = hook.pilot( target_ship, "board", "target_board" )
@@ -302,40 +312,38 @@ end
 
 -- Enemies wait for the player
 function trigger_ambush()
-   local jp = jump.get( system.cur(), mem.last_sys )
-   local x, y
+   local jp = jump.get( system.cur(), mem.last_sys ):pos()
+
+   local leader
    ambush = {}
+   for k,s in ipairs{ mem.aship, mem.bship, mem.bship } do
+      local pos = jp + vec2.newP( 2000+2000*rnd.rnd(), rnd.angle() )
+      local p = pilot.add( mem.aship, mem.target_faction, pos )
 
-   x = 4000 * rnd.rnd() - 2000
-   y = 4000 * rnd.rnd() - 2000
-   local pos = jp:pos() + vec2.new(x,y)
-   ambush[1] = pilot.add( mem.aship, mem.target_faction, pos )
-   x = 4000 * rnd.rnd() - 2000
-   y = 4000 * rnd.rnd() - 2000
-   pos = jp:pos() + vec2.new(x,y)
-   ambush[2] = pilot.add( mem.bship, mem.target_faction, pos )
-   x = 4000 * rnd.rnd() - 2000
-   y = 4000 * rnd.rnd() - 2000
-   pos = jp:pos() + vec2.new(x,y)
-   ambush[3] = pilot.add( mem.bship, mem.target_faction, pos )
+      p:setHostile(true)
+      p:memory().capturable = true
 
-   ambush[1]:setHostile()
-   ambush[2]:setHostile()
-   ambush[3]:setHostile()
-   ambush[1]:control()
-   ambush[2]:control()
-   ambush[3]:control()
-   ambush[1]:attack(player.pilot())
-   ambush[2]:attack(player.pilot())
-   ambush[3]:attack(player.pilot())
+      if not leader then
+         leader = p
+      else
+         p:setLeader(p)
+      end
+
+      table.insert( ambush, p )
+   end
+
+   pilotai.guard( ambush, jp + vec2.newP( 100, rnd.angle() ) )
 
    mem.msg = hook.timer( 1.0, "ambust_msg" )
 end
 
 -- Enemies explain that they are ambushing the player
 function ambust_msg()
-   for i = 1, 3 do
-      ambush[i]:comm( fmt.f( comms.ambush[rnd.rnd(1,#comms.ambush)], {plt=mem.name} ) )
+   for k,p in ipairs(ambush) do
+      if p:exists() then
+         p:comm( fmt.f( comms.ambush[rnd.rnd(1,#comms.ambush)], {plt=mem.name} ) )
+         return
+      end
    end
 end
 
@@ -352,8 +360,8 @@ function spawn_advisor ()
 end
 
 function hailme()
-    advisor:hailPlayer()
-    mem.hailie2 = hook.pilot(advisor, "hail", "hail_ad")
+   advisor:hailPlayer()
+   mem.hailie2 = hook.pilot(advisor, "hail", "hail_ad")
 end
 
 function hail_ad()
@@ -403,9 +411,9 @@ function hail( target )
       return
    end
 
-   -- Don't duplicate if in memory
+   -- Don't duplicate if in memory and can't talk to drones (for now?)
    local m = target:memory()
-   if m._seekndestroy then
+   if m._seekndestroy or m.isdrone then
       return
    end
    m._seekndestroy = true
@@ -419,7 +427,7 @@ function hail( target )
 
    -- Custom option
    local lbl = "seekndestroy_check"
-   local mmem = mem -- have to use auxiliary variable here
+   local mmem = mem -- have to use auxiliary variable here to set the upvalue
    local nextsys = mmem.mysys[mmem.cursys+1]
    ccomm.customComm( target, function ()
       if mmem.stage ~= 0 or system.cur() ~= mmem.mysys[mmem.cursys] or inlist( hailed, target )then
@@ -637,8 +645,8 @@ function land()
       lmisn.sfxVictory()
       vntk.msg( _("Good work, pilot!"), quotes.pay[rnd.rnd(1,#quotes.pay)].."\n\n"..fmt.reward(mem.credits) )
       player.pay( mem.credits )
-      mem.paying_faction:hit( rnd.rnd(1,2) )
-      pir.reputationNormalMission(rnd.rnd(2,3))
+      mem.paying_faction:hit( rnd.rnd(3,4) )
+      pir.reputationNormalMission(rnd.rnd(3,4))
       misn.finish( true )
    end
 end
@@ -739,6 +747,7 @@ end
 function target_board( p )
    mem.stage = 4
    clear_target_hook()
+   p:setDisable() -- Permanently disable
 
    vntk.msg( _("Target captured"), _("You board the ship and, after a short but intense firefight, are able to take the wanted outlaw alive. Time to hand them in to the authorities.") )
    p:setDisable() -- Permanently disable
@@ -748,8 +757,6 @@ function target_board( p )
    misn.osdActive( 3 )
    misn.markerRm(mem.marker)
    pilot.toggleSpawn(true)
-
-   player.unboard()
 end
 
 function clear_target_hook ()
