@@ -89,7 +89,7 @@ function accept ()
    vn.newCharacter( trixie )
    vn.music( onion.loops.hacker )
    vn.transition("electric")
-   vn.na(_([[You answer the incoming connection and some familiar holograms appear on-screen.]]))
+   vn.na(_([[You accept the incoming connection and some familiar holograms appear on-screen.]]))
    l337(fmt.f(_([["Heyo, how's it going {player}?"]]),
       {player=player.name()}))
    trixie(_([["Yo."]]))
@@ -202,7 +202,7 @@ function land ()
       vn.label("01_alarm_early")
       vn.disappear( {l337, trixie}, "electric" )
       vn.label("01_alarm")
-      vn.sfx( audio.newSource( 'snd/sounds/loops/alarm.ogg' ) ) -- Just one loop
+      vn.sfx( audio.newSoundData( 'snd/sounds/loops/alarm' ) ) -- Just one loop
       vn.na(_([[You open the command console and trigger the ship's emergency alarm system. The alarm system, designed for long-range planetary signalling, seems to be amplified and echoed by the spacedock structure, resulting in an onslaught of audible chaos. Everyone in the spacedock turns towards your ship: it looks like you got the attention of the entire floor.]]))
       vn.func( function () badthing = "alarm" end )
       vn.jump("01_cont")
@@ -441,7 +441,7 @@ You hear a beep.
       else
          l337(_([["What were you able to get?"]]))
          trixie(_([["I didn't have much time to choose, so I just randomly downloaded as much as bandwidth allowed, still going through it. From the little I've seen, there's some interesting account credentials, and some encrypted stuff that we have to unlock. All in all, a pretty good haul."]]))
-         l337(_([["Cool. Def share the tidbits. I've got some spare computational power to crack codes."]]))
+         l337(_([["Cool. Def share the titbits. I've got some spare computational power to crack codes."]]))
       end
       l337(_([["What are our next steps?"]]))
       trixie(_([["I've been thinking about what we talked about almost a cycle ago. We might be able to pull off something big, like really big."]]))
@@ -529,13 +529,13 @@ function breakin ()
    vn.func( function ()
       mem.failedhack = true
    end )
-   vn.music( 'snd/sounds/loops/alarm.ogg' )
+   vn.music( 'snd/sounds/loops/alarm' )
    trixie(_([["Shit, get out of there now!"]]))
    vn.jump("end")
 
    vn.label("mg_success")
    trixie(_([["Got it? Great! Let me access try to access the data."]]))
-   vn.music( 'snd/sounds/loops/alarm.ogg' )
+   vn.music( 'snd/sounds/loops/alarm' )
    trixie(_([["Shit, I'll try to get what I can, but you have to get out of there now!"]]))
    vn.jump("end")
 
@@ -587,14 +587,16 @@ function enter ()
          "Shark",
       }
       local baddies1 = fleet.add( 1, ships, fct_baddie(), spob.get("Wellen"):pos() )
+      local wp=targetsys:waypoints()
+
       pilotai.apply( baddies1, function (p)
          p:rename( fmt.f(_("Nexus {ship}"), {ship=p:ship():name()}))
          p:setHostile(true)
       end )
       pilotai.patrol( baddies1, {
-         vec2.new( 20e3, 9500 ),
-         vec2.new( 300, -3500 ),
-         vec2.new( -12e3, -5e3 ),
+         wp["onion04_1"],
+         wp["onion04_2"],
+         wp["onion04_3"],
       } )
 
       -- Player has to run away
@@ -722,6 +724,7 @@ function heartbeat ()
    if spam < 0 then
       player.msg(fmt.f(_("Trixie: See the {p}? Get closer!"),{p=l}), true )
       player.autonavReset( 5 )
+      spam = 15
    end
    hook.timer( 1, "heartbeat" )
 end
