@@ -92,7 +92,7 @@ local function meeting()
    if first then
       var.push("shadowvigil_first", false)
 
-      vn.na(_([[You dock with the Seiryuu and shut down your engines. At the airlock, you are welcomed by two nondescript crewmen in gray uniforms who tell you to follow them into the ship. They lead you through corridors and passages that seem to lead to the bridge. On the way, you can't help but look around you in wonder. The ship isn't anything you're used to seeing. While some parts can be identified as such common features as doors and viewports, a lot of the equipment in the compartments and niches seems strange, almost alien to you. Clearly the Seiryuu is not just any other Kestrel.]]))
+      vn.na(_([[You dock with the Seiryuu and shut down your engines. At the airlock, you are welcomed by two nondescript crewmen in grey uniforms who tell you to follow them into the ship. They lead you through corridors and passages that seem to lead to the bridge. On the way, you can't help but look around you in wonder. The ship isn't anything you're used to seeing. While some parts can be identified as such common features as doors and viewports, a lot of the equipment in the compartments and niches seems strange, almost alien to you. Clearly the Seiryuu is not just any other Kestrel.]]))
       vn.na(_([[On the bridge, you immediately spot - who else - the Seiryuu's captain, Rebina, seated in the captain's chair. The chair, too, is designed in the strange fashion that you've been seeing all over the ship. It sports several controls that you can't place, despite the fact that you're an experienced pilot yourself. The rest of the bridge is no different. All the regular stations and consoles seem to be there, but there are some others whose purpose you can only guess.]]))
       rebina(fmt.f(_([[Rebina swivels the chair around and smiles when she sees you. "Ah, {player}," she says. "How good of you to come. I was hoping you'd get my invitation, since I was quite pleased with your performance last time. And I'm not the only one. As it turns out Jorek seems to have taken a liking to you as well. He may seem rough, but he's a good man at heart."]]),
          {player=player.name()}))
@@ -142,6 +142,7 @@ function accept_m()
    mem.alive = {true, true, true} -- Keep track of the escorts. Update this when they die.
    mem.stage = 1 -- Keeps track of the mission stage
    mem.nextsys = lmisn.getNextSystem(system.cur(), misssys[mem.stage]) -- This variable holds the system the player is supposed to jump to NEXT.
+   -- Will always be the same as rebinasys, right ?
    mem.seirsys = system.cur() -- Remember where the Seiryuu is.
    mem.origin = system.cur() -- The place where the AI ships spawn from.
    mem.chattered = false
@@ -159,11 +160,11 @@ function accept_m()
    mem.marker = misn.markerAdd(misssys[1], "low")
 
    misn.osdCreate(_("Shadow Vigil"), {
-     fmt.f(_("Fly to the {sys} system and join the other escorts"), {sys=misssys[1]}),
-     fmt.f(_("Follow the group to {spb} and land"),{spb=refuelsys}),
-     _("Follow the flight leader to the rendezvous location"),
-     _("Escort the Imperial diplomat"),
-     fmt.f(_("Report back to Rebina ({sys} system)"),{sys=rebinasys}),
+      fmt.f(_("Fly to the {sys} system and join the other escorts"), {sys=misssys[1]}),
+      fmt.f(_("Follow the group to {spb} and land"),{spb=refuelsys}),
+      _("Follow the flight leader to the rendezvous location"),
+      _("Escort the Imperial diplomat"),
+      fmt.f(_("Report back to Rebina ({sys} system)"),{sys=rebinasys}),
    })
 
    hook.land("land")
@@ -206,20 +207,28 @@ function takeoff()
    end
 end
 
+local function spawn_seiryuu(ready)
+   local where=rebinasys:waypoints("shadowvigil_seiryuu")
+
+   seiryuu = pilot.add( "Pirate Kestrel", shadow.fct_fourwinds(), where, _("Seiryuu"), {ai="trader"} )
+   seiryuu:setInvincible(true)
+   if ready then
+      seiryuu:setActiveBoard(true)
+      seiryuu:setHilight(true)
+      seiryuu:setVisplayer(true)
+      seiryuu:control(true)
+      hook.pilot(seiryuu, "board", "board")
+   end
+end
+
 -- Function hooked to jumpin AND takeoff. Handles events that should occur in either case.
 function enter()
    if mem.stage == 0 and system.cur() == rebinasys then -- put Rebina's ship
-      seiryuu = pilot.add( "Pirate Kestrel", shadow.fct_fourwinds(), vec2.new(0, -2000), _("Seiryuu"), {ai="trader"} )
-      seiryuu:control(true)
-      seiryuu:setActiveBoard(true)
-      seiryuu:setInvincible(true)
-      seiryuu:setHilight(true)
-      seiryuu:setVisplayer(true)
-      hook.pilot(seiryuu, "board", "board")
-
+      spawn_seiryuu(true)
    elseif system.cur() == misssys[1] and mem.stage == 1 and mem.missend == false then
       -- case enter system where escorts wait
-      escorts = fleet.add( 3, "Lancelot", shadow.fct_fourwinds(), vec2.new(0, 0), _("Four Winds Escort"), {ai="baddie_norun"} )
+      local rend_point = misssys[1]:waypoints("shadowvigil_rend")
+      escorts = fleet.add( 3, "Lancelot", shadow.fct_fourwinds(), rend_point, _("Four Winds Escort"), {ai="baddie_norun"} )
       for i, j in ipairs(escorts) do
          if not mem.alive[i] then j:rm() end -- Dead escorts stay dead.
          if j:exists() then
@@ -228,21 +237,12 @@ function enter()
             hook.pilot(j, "death", "escortDeath")
          end
       end
-      local rend_point = vec2.new(0,0)
       mem.start_marker = system.markerAdd( rend_point, _("Rendezvous point") )
       mem.proxy = hook.timer(0.5, "proximity", {location = rend_point, radius = 500, funcname = "escortStart"})
 
    elseif system.cur()==mem.seirsys then -- not escorting.
       -- case enter system where Seiryuu is
-      seiryuu = pilot.add( "Pirate Kestrel", shadow.fct_fourwinds(), vec2.new(0, -2000), _("Seiryuu"), {ai="trader"} )
-      seiryuu:setInvincible(true)
-      if mem.missend then
-         seiryuu:setActiveBoard(true)
-         seiryuu:setHilight(true)
-         seiryuu:setVisplayer(true)
-         seiryuu:control()
-         hook.pilot(seiryuu, "board", "board")
-      end
+      spawn_seiryuu(mem.missend)
    end
 end
 
@@ -303,7 +303,9 @@ function jumpin()
             end
          end
       elseif system.cur() == misssys[3] then -- case join up with diplomat
-         diplomat = pilot.add( "Gawain", shadow.fct_diplomatic(), vec2.new(0, 0), _("Imperial Diplomat") )
+         local dip_point = misssys[3]:waypoints("shadowvigil_diplomat")
+
+         diplomat = pilot.add( "Gawain", shadow.fct_diplomatic(), dip_point, _("Imperial Diplomat") )
          hook.pilot(diplomat, "death", "diplomatDeath")
          hook.pilot(diplomat, "jump", "diplomatJump")
          diplomat:setSpeedLimit( 130 )
@@ -314,7 +316,7 @@ function jumpin()
          diplomat:setHilight(true)
          diplomat:setVisplayer()
          diplomat:setVisible() -- Hack to make ambushes more reliable.
-         mem.proxy = hook.timer(0.5, "proximity", {location = vec2.new(0, 0), radius = 500, funcname = "escortNext"})
+         mem.proxy = hook.timer(0.5, "proximity", {location = dip_point, radius = 500, funcname = "escortNext"})
          for i, j in ipairs(escorts) do
             if j:exists() then
                j:follow(diplomat,true) -- Follow the diplomat.
@@ -323,20 +325,21 @@ function jumpin()
          hook.timer(5.0, "chatter", {pilot = escorts[1], text = _("Alright folks, there he is. You know your orders. Stick to him. Don't let anyone touch him on the way to the rendezvous.")})
          hook.timer(12.0, "chatter", {pilot = escorts[2], text = _("Two, copy.")})
          hook.timer(14.0, "chatter", {pilot = escorts[3], text = _("Three, copy.")})
-     elseif system.cur() == misssys[4] then -- case rendezvous with Dvaered diplomat
+      elseif system.cur() == misssys[4] then -- case rendezvous with Dvaered diplomat
          for i, j in ipairs(escorts) do
             if j:exists() then
                j:follow(diplomat,true) -- Follow the diplomat.
             end
          end
-         dvaerplomat = pilot.add( "Dvaered Vigilance", "Dvaered", vec2.new(2000, 4000) )
+         local meetpoint = misssys[4]:waypoints("shadowvigil_meetpoint")
+         dvaerplomat = pilot.add( "Dvaered Vigilance", "Dvaered", meetpoint )
          dvaerplomat:control()
          dvaerplomat:setHilight(true)
          dvaerplomat:setVisplayer()
          dvaerplomat:setDir(math.pi)
          dvaerplomat:setFaction( shadow.fct_diplomatic() )
          diplomat:setInvincible(true)
-         diplomat:moveto(vec2.new(1850, 4000), true)
+         diplomat:moveto(meetpoint + vec2.new(-150, 0), true)
          mem.diplomatidle = hook.pilot(diplomat, "idle", "diplomatIdle")
       else -- case en route, handle escorts flying to the next system, possibly combat
          for i, j in ipairs(escorts) do
@@ -362,6 +365,7 @@ function jumpin()
                {"Pirate Ancestor", "Pirate Hyena", "Pirate Hyena"},
                {"Pirate Ancestor", "Pirate Vendetta", "Pirate Hyena", "Pirate Hyena"}
             }
+            -- should not be made system-dependent -> keep the absolute (0,0)
             ambush = fleet.add( 1,  ambush_ships[3-mem.jp2go], shadow.fct_pirates(), vec2.new(0, 0), _("Pirate Attacker"), {ai="baddie_norun"} )
             mem.kills = 0
             for i, j in ipairs(ambush) do
@@ -512,7 +516,7 @@ end
 -- As soon as the diplomat is at its destination, set up final cutscene.
 function diplomatIdle()
    local mypos = {} -- Relative positions to the Dvaered diplomat.
-   mypos[1] = vec2.new(0, 130)
+   mypos[1] = vec2.new(0, 130)   -- offsets
    mypos[2] = vec2.new(-85, -65)
    mypos[3] = vec2.new(85, -65)
 
@@ -535,7 +539,7 @@ function diplomatCutscene()
    camera.set(dvaerplomat, false, 500)
 
    hook.timer(1.0, "chatter", {pilot = diplomat, text = _("This is Empire zero-zero-four. Transmitting clearance code now.")})
-   hook.timer(10.0, "chatter", {pilot = dvaerplomat, text = _("Empire zero-zero-four, your code checks out. Commence boarding maneuvers.")})
+   hook.timer(10.0, "chatter", {pilot = dvaerplomat, text = _("Empire zero-zero-four, your code checks out. Commence boarding manoeuvres.")})
    hook.timer(17.0, "diplomatGo")
    hook.timer(21.0, "chatter", {pilot = escorts[1], text = _("This is your leader, you're all clear. Execute, execute, execute!")})
    hook.timer(21.5, "killDiplomats")
