@@ -1,6 +1,104 @@
 --[[
    Script to update outfits and ships from a saved game in the case they don't exist.
 --]]
+local fmt = require "format"
+local changes_done = {}
+local save_updated
+
+--[[
+   Run before anything is done, so it can be used to store what was changed.
+--]]
+function start ()
+   changes_done = {}
+   save_updated = false
+   naev.cache().save_updater = {}
+end
+
+--[[
+   Run after finished processing. Allows doing additional changes as necessary.
+--]]
+function finish ()
+   if not save_updated then
+      return
+   end
+   local cache = naev.cache().save_updater
+   cache.split_list = {}
+
+   -- Old cores that now use the primary / secondary system (0.13.0)
+   local split = {
+      ["Krain Patagium Engine"]                 = true,
+      ["Melendez Mammoth XL Engine"]            = true,
+      ["Nexus Bolt 6500 Engine"]                = true,
+      ["Tricon Typhoon II Engine"]              = true,
+      ["Unicorp Eagle 6500 Engine"]             = true,
+      ["Melendez Buffalo XL Engine"]            = true,
+      ["Nexus Arrow 1400 Engine"]               = true,
+      ["Tricon Cyclone II Engine"]              = true,
+      ["Unicorp Falcon 1400 Engine"]            = true,
+      ["Melendez Ox XL Engine"]                 = true,
+      ["Nexus Dart 360 Engine"]                 = true,
+      ["Tricon Zephyr II Engine"]               = true,
+      ["Unicorp Hawk 360 Engine"]               = true,
+      ["Milspec Orion 9901 Core System"]        = true,
+      ["Milspec Thalos 9802 Core System"]       = true,
+      ["Unicorp PT-1750 Core System"]           = true,
+      ["Milspec Orion 5501 Core System"]        = true,
+      ["Milspec Thalos 5402 Core System"]       = true,
+      ["Unicorp PT-310 Core System"]            = true,
+      ["Milspec Orion 3701 Core System"]        = true,
+      ["Milspec Thalos 3602 Core System"]       = true,
+      ["Unicorp PT-68 Core System"]             = true,
+      ["Unicorp D-72 Heavy Plating"]            = true,
+      ["S&K Superheavy Combat Plating"]         = true,
+      ["Unicorp D-38 Medium Plating"]           = true,
+      ["S&K Medium-Heavy Combat Plating"]       = true,
+      ["Unicorp D-9 Light Plating"]             = true,
+      ["S&K Light Combat Plating"]              = true,
+      ["Nexus Light Stealth Plating"]           = true,
+      -- Updates for even older cores from 0.11.0 to 0.12.0
+      ["Unicorp PT-2200 Core System"]           = true,
+      ["Unicorp PT-500 Core System"]            = true,
+      -- Updates for even older cores from 0.10.0 to 0.11.0
+      ["Unicorp D-68 Heavy Plating"]            = true,
+      ["Unicorp D-24 Medium Plating"]           = true,
+      ["Unicorp D-4 Light Plating"]             = true,
+      -- Updates for even older cores from 0.8.2 to 0.9.0
+      ["Milspec Prometheus 9803 Core System"]   = true,
+      ["Milspec Prometheus 5403 Core System"]   = true,
+      ["Milspec Prometheus 3603 Core System"]   = true,
+      ["Milspec Aegis 9801 Core System"]        = true,
+      ["Milspec Aegis 5401 Core System"]        = true,
+      ["Milspec Aegis 3601 Core System"]        = true,
+   }
+
+   if #changes_done > 0 then
+      for original,value in pairs(changes_done) do
+         if split[original] then
+            player.outfitAdd( value.new, value.q ) -- Have to add an additional core to compensate
+            print( fmt.f("   {original} => {new} x2 [{q}]", {original=original, new=value.new, q=value.q} ) )
+
+            -- Used to inform the updater event that cores probably need some checking
+            cache.split_list[value.new] = true
+            cache.split_cores = true
+         elseif value.new ~= nil then
+            print( fmt.f("   {original} => {new} [{q}]", {original=original, new=value.new, q=value.q} ) )
+         else
+            print( fmt.f("   {original} => nil [{q}]", {original=original, q=value.q} ) )
+         end
+      end
+   end
+end
+
+local function apply_change( original, new, q )
+   local value = changes_done[original]
+   if value then
+      value.q = value.q + q
+   else
+      changes_done[original] = { new=new, q=q }
+   end
+   save_updated = true
+   return new
+end
 
 --[[
    The format is ["oldname"] = newvalue where newvalue can either take a string
@@ -9,13 +107,14 @@
 --]]
 local ship_list = {
    ["Proteron Derivative"] = "Proteron Dalton",
-   ["Proteron Kahan"] = "Proteron Gauss",
+   ["Proteron Kahan"]      = "Proteron Gauss",
 }
+
 --[[--
    Takes an ship name and should return either a new ship name or the amount of credits to give back to the player.
 --]]
-function ship( name )
-   return ship_list[name]
+function ship( name, q )
+   return apply_change( name, ship_list[name], q )
 end
 
 --[[
@@ -24,54 +123,114 @@ end
    value indicating the amount of credits to refund the player.
 --]]
 local outfit_list = {
+   -- Below is a list of changes from 0.12.0 to 0.13.0
+   ["Ratchet Point Defense"]              = "Ratchet Point Defence",
+   ["Racing Trophy"]                      = "Racing Trophy (Silver)", -- getting the gold is now much harder
+   ["Avatar of Sirichana"]                = "Avatar of the Sirichana",
+   ["Auxiliary Proccessing Unit I"]       = "Auxiliary Processing Unit I", -- codespell:ignore Proccessing
+   ["Auxiliary Proccessing Unit II"]      = "Auxiliary Processing Unit II", -- codespell:ignore Proccessing
+   ["Auxiliary Proccessing Unit III"]     = "Auxiliary Processing Unit III", -- codespell:ignore Proccessing
+   ["Auxiliary Proccessing Unit IV"]      = "Auxiliary Processing Unit IV", -- codespell:ignore Proccessing
+   ["Adaptive Stealth Plating"]           = "Adaptive Camouflage Plating",
+   ["Nexus Stealth Coating"]              = "Nexus Concealment Coating",
+   ["Camouflage Burster"]                 = "Stealth Burster",
+
+   -- Multicore transformation (engines).
+   -- Each core in the left is split in 2 cores the right, one in the main core slot, the other one on the secondary core slot.
+   -- See finish() above.
+   ["Krain Patagium Engine"]              = "Krain Patagium Twin Engine",
+   ["Melendez Mammoth XL Engine"]         = "Melendez Mammoth Engine",
+   ["Nexus Bolt 6500 Engine"]             = "Nexus Bolt 3000 Engine",
+   ["Tricon Typhoon II Engine"]           = "Tricon Typhoon Engine",
+   ["Unicorp Eagle 6500 Engine"]          = "Unicorp Eagle 3000 Engine",
+   ["Melendez Buffalo XL Engine"]         = "Melendez Buffalo Engine",
+   ["Nexus Arrow 1400 Engine"]            = "Nexus Arrow 700 Engine",
+   ["Tricon Cyclone II Engine"]           = "Tricon Cyclone Engine",
+   ["Unicorp Falcon 1400 Engine"]         = "Unicorp Falcon 700 Engine",
+   ["Melendez Ox XL Engine"]              = "Melendez Ox Engine",
+   ["Nexus Dart 360 Engine"]              = "Nexus Dart 160 Engine",
+   ["Tricon Zephyr II Engine"]            = "Tricon Zephyr Engine",
+   ["Unicorp Hawk 360 Engine"]            = "Unicorp Hawk 160 Engine",
+
+   -- Just renamings
+   ["Nexus Ultralight Stealth Plating"]   = "Nexus Shadow Weave",
+   ["Nexus Medium Stealth Plating"]       = "Nexus Ghost Weave",
+   ["Nexus Heavy Stealth Plating"]        = "Nexus Phantasm Weave",
+   ["S&K Ultralight Combat Plating"]      = "S&K Skirmish Plating",
+   ["S&K Medium Combat Plating"]          = "S&K Battle Plating",
+   ["S&K Heavy Combat Plating"]           = "S&K War Plating",
+
+   -- Multicore transformation (hulls).
+   -- Each core in the left is split in 2 cores the right, one in the main core slot, the other one on the secondary core slot.
+   -- See finish() above.
+   ["Nexus Light Stealth Plating"]        = "Nexus Shadow Weave",
+   ["Unicorp D-72 Heavy Plating"]         = "Unicorp D-58 Heavy Plating",
+   ["S&K Superheavy Combat Plating"]      = "S&K War Plating",
+   ["Unicorp D-38 Medium Plating"]        = "Unicorp D-23 Medium Plating",
+   ["S&K Medium-Heavy Combat Plating"]    = "S&K Battle Plating",
+   ["Unicorp D-9 Light Plating"]          = "Unicorp D-2 Light Plating",
+   ["S&K Light Combat Plating"]           = "S&K Skirmish Plating",
+   ["Milspec Orion 9901 Core System"]     = "Milspec Orion 8601 Core System",
+   ["Milspec Thalos 9802 Core System"]    = "Milspec Thalos 8502 Core System",
+   ["Unicorp PT-1750 Core System"]        = "Unicorp PT-440 Core System",
+   ["Milspec Orion 5501 Core System"]     = "Milspec Orion 4801 Core System",
+   ["Milspec Thalos 5402 Core System"]    = "Milspec Thalos 4702 Core System",
+   ["Unicorp PT-310 Core System"]         = "Unicorp PT-200 Core System",
+   ["Milspec Orion 3701 Core System"]     = "Milspec Orion 2301 Core System",
+   ["Milspec Thalos 3602 Core System"]    = "Milspec Thalos 2202 Core System",
+   ["Unicorp PT-68 Core System"]          = "Unicorp PT-16 Core System",
+
    -- Below is a list of changes from 0.11.0 to 0.12.0
-   ["Unicorp PT-2200 Core System"] = "Unicorp PT-1750 Core System",
-   ["Unicorp PT-500 Core System"] = "Unicorp PT-440 Core System",
+   ["Unicorp PT-2200 Core System"]        = "Unicorp PT-440 Core System",
+   ["Unicorp PT-500 Core System"]         = "Unicorp PT-440 Core System",
+
    -- Below is a list of changes from 0.10.0 to 0.11.0
-   ["Unicorp D-68 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
-   ["Unicorp D-48 Heavy Plating"] = "Unicorp D-58 Heavy Plating",
-   ["Unicorp D-24 Medium Plating"] = "Unicorp D-38 Medium Plating",
-   ["Unicorp D-12 Medium Plating"] = "Unicorp D-23 Medium Plating",
-   ["Unicorp D-4 Light Plating"] = "Unicorp D-9 Light Plating",
-   ["Unicorp Eagle 7000 Engine"] = "Unicorp Eagle 6500 Engine",
-   ["Nexus Bolt 3500 Engine"] = "Nexus Bolt 3000 Engine",
-   ["Unicorp Falcon 1300 Engine"] = "Unicorp Falcon 1400 Engine",
-   ["Unicorp Hawk 350 Engine"] = "Unicorp Hawk 360 Engine",
-   ["Nexus Dart 150 Engine"] = "Nexus Dart 160 Engine",
-   ["Razor MK1"] = "Razor Artillery S1",
-   ["Razor MK2"] = "Razor Artillery S2",
-   ["Slicer"] = "Razor Artillery S3",
-   ["Razor Turret MK1"] = 50e3,
-   ["Razor Turret MK2"] = "Razor Battery S2",
-   ["Tesla Cannon"] = 780e3,
-   ["Heavy Razor Turret"] = "Disruptor Battery S2",
-   ["Fidelity Bay"] = "Sirius Fidelity Bay",
+   ["Unicorp D-68 Heavy Plating"]         = "Unicorp D-72 Heavy Plating",
+   ["Unicorp D-48 Heavy Plating"]         = "Unicorp D-58 Heavy Plating",
+   ["Unicorp D-24 Medium Plating"]        = "Unicorp D-38 Medium Plating",
+   ["Unicorp D-12 Medium Plating"]        = "Unicorp D-23 Medium Plating",
+   ["Unicorp D-4 Light Plating"]          = "Unicorp D-9 Light Plating",
+   ["Unicorp Eagle 7000 Engine"]          = "Unicorp Eagle 6500 Engine",
+   ["Nexus Bolt 3500 Engine"]             = "Nexus Bolt 3000 Engine",
+   ["Unicorp Falcon 1300 Engine"]         = "Unicorp Falcon 1400 Engine",
+   ["Unicorp Hawk 350 Engine"]            = "Unicorp Hawk 360 Engine",
+   ["Nexus Dart 150 Engine"]              = "Nexus Dart 160 Engine",
+   ["Razor MK1"]                          = "Razor Artillery S1",
+   ["Razor MK2"]                          = "Razor Artillery S2",
+   ["Slicer"]                             = "Razor Artillery S3",
+   ["Razor Turret MK1"]                   = 50e3,
+   ["Razor Turret MK2"]                   = "Razor Battery S2",
+   ["Tesla Cannon"]                       = 780e3,
+   ["Heavy Razor Turret"]                 = "Disruptor Battery S2",
+   ["Fidelity Bay"]                       = "Sirius Fidelity Bay",
+
    -- Below is a list of changes from 0.9.0 to 0.10.0
-   ["Drone Fighter Bay"] = "Drone Bay",
-   ["Empire Lancelot Fighter Bay"] = "Empire Lancelot Bay",
-   --["Fidelity Fighter Bay"] = "Fidelity Bay",
-   ["Hyena Fighter Dock"] = "Hyena Bay",
-   ["Hyena Fighter Bay"] = "Hyena Dock",
-   ["Lancelot Fighter Bay"] = "Lancelot Bay",
-   ["Pirate Hyena Fighter Dock"] = "Pirate Hyena Bay",
-   ["Pirate Hyena Fighter Bay"] = "Pirate Hyena Dock",
-   ["Proteron Derivative Bay"] = "Proteron Dalton Bay",
-   ["Proteron Derivative Fighter Bay"] = "Proteron Dalton Bay",
-   ["Soromid Brigand Fighter Bay"] = "Soromid Brigand Bay",
-   ["Thurion Perspicacity Fighter Dock"] = "Thurion Perspicacity Bay",
-   ["Thurion Perspicacity Fighter Bay"] = "Thurion Perspicacity Dock",
-   ["Za'lek Bomber Drone Fighter Dock"] = "Za'lek Bomber Drone Bay",
-   ["Za'lek Bomber Drone Fighter Bay"] = "Za'lek Bomber Drone Mini Bay",
-   ["Za'lek Heavy Drone Fighter Dock"] = "Za'lek Heavy Drone Bay",
-   ["Za'lek Heavy Drone Fighter Bay"] = "Za'lek Heavy Drone Mini Bay",
-   ["Za'lek Light Drone Fighter Dock"] = "Za'lek Light Drone Bay",
-   ["Za'lek Light Drone Fighter Bay"] = "Za'lek Light Drone Mini Bay",
-   ["Unicorp Banshee Launcher"] = 35e3,
-   ["Unicorp Mace Launcher"] = 19e3,
-   ["Unicorp Fury Launcher"] = 65e3,
-   ["Unicorp Headhunter Launcher"] = 70e3,
-   ["Unicorp Medusa Launcher"] = 73e3,
-   ["Unicorp Vengeance Launcher"] = 78e3,
+   ["Drone Fighter Bay"]                  = "Drone Bay",
+   ["Empire Lancelot Fighter Bay"]        = "Empire Lancelot Bay",
+   --["Fidelity Fighter Bay"]             = "Fidelity Bay",
+   ["Hyena Fighter Dock"]                 = "Hyena Bay",
+   ["Hyena Fighter Bay"]                  = "Hyena Dock",
+   ["Lancelot Fighter Bay"]               = "Lancelot Bay",
+   ["Pirate Hyena Fighter Dock"]          = "Pirate Hyena Bay",
+   ["Pirate Hyena Fighter Bay"]           = "Pirate Hyena Dock",
+   ["Proteron Derivative Bay"]            = "Proteron Dalton Bay",
+   ["Proteron Derivative Fighter Bay"]    = "Proteron Dalton Bay",
+   ["Soromid Brigand Fighter Bay"]        = "Soromid Brigand Bay",
+   ["Thurion Perspicacity Fighter Dock"]  = "Thurion Perspicacity Bay",
+   ["Thurion Perspicacity Fighter Bay"]   = "Thurion Perspicacity Dock",
+   ["Za'lek Bomber Drone Fighter Dock"]   = "Za'lek Bomber Drone Bay",
+   ["Za'lek Bomber Drone Fighter Bay"]    = "Za'lek Bomber Drone Mini Bay",
+   ["Za'lek Heavy Drone Fighter Dock"]    = "Za'lek Heavy Drone Bay",
+   ["Za'lek Heavy Drone Fighter Bay"]     = "Za'lek Heavy Drone Mini Bay",
+   ["Za'lek Light Drone Fighter Dock"]    = "Za'lek Light Drone Bay",
+   ["Za'lek Light Drone Fighter Bay"]     = "Za'lek Light Drone Mini Bay",
+   ["Unicorp Banshee Launcher"]           = 35e3,
+   ["Unicorp Mace Launcher"]              = 19e3,
+   ["Unicorp Fury Launcher"]              = 65e3,
+   ["Unicorp Headhunter Launcher"]        = 70e3,
+   ["Unicorp Medusa Launcher"]            = 73e3,
+   ["Unicorp Vengeance Launcher"]         = 78e3,
+
    -- Below are the 0.9.x naming scheme and prices
    ["BioPlasma Claw Stage 1"] = 8500,
    ["BioPlasma Claw Stage 2"] = 10600,
@@ -235,6 +394,7 @@ local outfit_list = {
    ["Ultralight Shell Stage 1"] = 65000,
    ["Ultralight Shell Stage 2"] = 97500,
    ["Ultralight Shell Stage X"] = 130000,
+
    -- Below are the 0.8.x naming scheme and prices
    ["BioPlasma Organ Stage 1"] = 18000,
    ["BioPlasma Organ Stage 2"] = 18000,
@@ -372,16 +532,16 @@ local outfit_list = {
    ["Ultralight Bioship Shell Stage 1"] = 65000,
    ["Ultralight Bioship Shell Stage 2"] = 65000,
    ["Ultralight Bioship Shell Stage X"] = 65000,
+
    -- Below is a list of changes from 0.8.2 to 0.9.0
    ["Unicorp PT-1000 Core System"] = "Unicorp PT-1750 Core System", -- Modified for 0.12.0
    ["Unicorp PT-900 Core System"] = "Unicorp PT-440 Core System", -- Modified for 0.12.0
    ["Unicorp PT-600 Core System"] = "Unicorp PT-310 Core System",
    ["Unicorp PT-100 Core System"] = "Unicorp PT-16 Core System",
-   ["Unicorp Hawk 150 Engine"] = "Nexus Dart 160 Engine", -- Modified for 0.11.0
-   ["Unicorp Falcon 550 Engine"] = "Unicorp Falcon 1400 Engine",
+   ["Unicorp Hawk 150 Engine"] = "Unicorp Hawk 160 Engine", -- Modified for 0.11.0
+   ["Unicorp Falcon 550 Engine"] = "Unicorp Falcon 700 Engine",
    ["Unicorp Falcon 1200 Engine"] = "Unicorp Falcon 1400 Engine",
-   ["Unicorp Eagle 6500 Engine"] = "Unicorp Eagle 6500 Engine",
-   ["Unicorp Eagle 4500 Engine"] = "Unicorp Eagle 6500 Engine",
+   ["Unicorp Eagle 4500 Engine"] = "Unicorp Eagle 3000 Engine",
    ["Unicorp D-8 Medium Plating"] = "Unicorp D-23 Medium Plating",
    ["Unicorp D-20 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
    ["Unicorp D-16 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
@@ -417,32 +577,22 @@ local outfit_list = {
    ["Plasma Blaster MK3"] = 26e3,
    ["Plasma Blaster MK2"] = 17e3,
    ["Plasma Blaster MK1"] = 9e3,
-   ["Nexus Dart 300 Engine"] = "Nexus Dart 160 Engine", -- Modified for 0.11.0
-   ["Nexus Bolt 6500 Engine"] = "Nexus Bolt 3000 Engine",
+   ["Nexus Dart 300 Engine"] = "Nexus Dart 360 Engine",
    ["Nexus Bolt 4500 Engine"] = "Nexus Bolt 3000 Engine",
    ["Nexus Arrow 550 Engine"] = "Nexus Arrow 700 Engine",
-   ["Nexus Arrow 1200 Engine"] = "Nexus Arrow 700 Engine",
-   ["Milspec Prometheus 9803 Core System"] = "Milspec Thalos 9802 Core System",
-   ["Milspec Prometheus 8503 Core System"] = "Milspec Thalos 8502 Core System",
-   ["Milspec Prometheus 5403 Core System"] = "Milspec Thalos 5402 Core System",
-   ["Milspec Prometheus 4703 Core System"] = "Milspec Thalos 4702 Core System",
-   ["Milspec Prometheus 3603 Core System"] = "Milspec Thalos 3602 Core System",
-   ["Milspec Prometheus 2203 Core System"] = "Milspec Thalos 2202 Core System",
-   ["Milspec Hermes 9802 Core System"] = "Milspec Orion 9901 Core System",
+   ["Nexus Arrow 1200 Engine"] = "Nexus Arrow 1400 Engine",
+   ["Milspec Prometheus 9803 Core System"] = "Milspec Prometheus 8503 Core System",
+   ["Milspec Prometheus 5403 Core System"] = "Milspec Prometheus 4703 Core System",
+   ["Milspec Prometheus 3603 Core System"] = "Milspec Prometheus 2203 Core System",
+   ["Milspec Hermes 9802 Core System"] = "Milspec Orion 8601 Core System",
    ["Milspec Hermes 8502 Core System"] = "Milspec Orion 8601 Core System",
-   ["Milspec Hermes 5402 Core System"] = "Milspec Orion 5501 Core System",
+   ["Milspec Hermes 5402 Core System"] = "Milspec Orion 4801 Core System",
    ["Milspec Hermes 4702 Core System"] = "Milspec Orion 4801 Core System",
-   ["Milspec Hermes 3602 Core System"] = "Milspec Orion 3701 Core System",
+   ["Milspec Hermes 3602 Core System"] = "Milspec Orion 2301 Core System",
    ["Milspec Hermes 2202 Core System"] = "Milspec Orion 2301 Core System",
-   ["Milspec Aegis 9801 Core System"] = "Milspec Thalos 9802 Core System",
-   ["Milspec Aegis 8501 Core System"] = "Milspec Thalos 8502 Core System",
-   ["Milspec Aegis 5401 Core System"] = "Milspec Thalos 5402 Core System",
-   ["Milspec Aegis 4701 Core System"] = "Milspec Thalos 4702 Core System",
-   ["Milspec Aegis 3601 Core System"] = "Milspec Thalos 3602 Core System",
-   ["Milspec Aegis 2201 Core System"] = "Milspec Thalos 2202 Core System",
-   ["Melendez Ox Engine"] = "Melendez Ox XL Engine",
-   ["Melendez Mammoth Engine"] = "Melendez Mammoth XL Engine",
-   ["Melendez Buffalo Engine"] = "Melendez Buffalo XL Engine",
+   ["Milspec Aegis 9801 Core System"] = "Milspec Aegis 8501 Core System",
+   ["Milspec Aegis 5401 Core System"] = "Milspec Aegis 4701 Core System",
+   ["Milspec Aegis 3601 Core System"] = "Milspec Aegis 2201 Core System",
    ["Mass Driver MK3"] = "Mass Driver",
    ["Mass Driver MK2"] = "Mass Driver",
    ["Mass Driver MK1"] = "Mass Driver",
@@ -604,26 +754,36 @@ local outfit_list = {
    --]]
    ["Battery"] = "Battery I",
 }
+
 --[[--
    Takes an outfit name and should return either a new outfit name or the amount of credits to give back to the player.
 --]]
-function outfit( name )
-   return outfit_list[name]
+function outfit( name, q )
+   return apply_change( name, outfit_list[name], q )
 end
 
-local license_list = {
+local licence_list = {
    -- Below is a list of changes from 0.9.0-alpha to 0.9.0-beta
-   ["Heavy Combat Vessel License"] = "Heavy Combat Vessel",
-   ["Heavy Weapon License"] = "Heavy Weapon",
-   ["Large Civilian Vessel License"] = "Large Civilian Vessel",
-   ["Light Combat Vessel License"] = "Light Combat Vessel",
-   ["Medium Combat Vessel License"] = "Medium Combat Vessel",
-   ["Medium Weapon License"] = "Medium Weapon",
-   ["Mercenary License"] = "Mercenary",
+   ["Heavy Combat Vessel Licence"] = "Heavy Combat Vessel",
+   ["Heavy Weapon Licence"] = "Heavy Weapon",
+   ["Large Civilian Vessel Licence"] = "Large Civilian Vessel",
+   ["Light Combat Vessel Licence"] = "Light Combat Vessel",
+   ["Medium Combat Vessel Licence"] = "Medium Combat Vessel",
+   ["Medium Weapon Licence"] = "Medium Weapon",
+   ["Mercenary Licence"] = "Mercenary",
 }
 --[[--
-   Takes a license name and should return either a new license name or the amount of credits to give back to the player.
+   Takes a licence name and should return either a new licence name or the amount of credits to give back to the player.
 --]]
-function license( name )
-   return license_list[name]
+function licence( name, q )
+   return apply_change( name, licence_list[name], q )
+end
+
+local unidiff_list = {
+   ["heavy_combat_vessel_license"] = "heavy_combat_vessel_licence",
+   ["heavy_weapons_license"] = "heavy_weapons_license",
+}
+function unidiff( name )
+   -- Internals stuff so we don't expose to the player
+   return  unidiff_list[name]
 end
