@@ -4,23 +4,22 @@
 
 --]]
 local vn = require "vn"
-local mt = require 'merge_tables'
 
 local tutnel = {}
 
 tutnel.nelly = {
-   portrait = "nelly.webp",
-   image = "nelly.webp",
+   portrait = "nelly",
+   image = "nelly",
    name = _("Nelly"),
-   color = nil,
+   colour = nil,
    transition = nil, -- Use default
 }
 
 function tutnel.vn_nelly( params )
    return vn.Character.new( tutnel.nelly.name,
-         mt.merge_tables( {
+         tmerge( {
             image=tutnel.nelly.image,
-            color=tutnel.nelly.colour,
+            colour=tutnel.nelly.colour,
          }, params) )
 end
 
@@ -32,6 +31,7 @@ end
 tutnel.reward = {
    nelly01 = 80e3,
    nelly02 = 120e3,
+   nelly03 = 57928, -- Spare change
 }
 
 return tutnel
