@@ -12,8 +12,8 @@ local zpp = {}
 
 -- Fullname: Noona Sanderaite
 zpp.noona = {
-   portrait = "noona.png",
-   image = "noona.png",
+   portrait = "noona",
+   image = "noona",
    name = _("Noona"),
    colour = { 1, 0.8, 0.8},
    transition = "hexagon",
@@ -36,10 +36,10 @@ end
 zpp.rewards = {
    zpp01 = 200e3,
    zpp02 = 300e3,
-   zpp03 = 200e3, -- + "Heavy Weapons Combat License" permission
+   zpp03 = 200e3, -- + "Heavy Weapons Combat Licence" permission
    zpp04 = 400e3,
    --zpp05 = 0, -- No payment, really small flashback
-   zpp06 = 500e3, -- + "Heavy Combat Vessel License" permission
+   zpp06 = 500e3, -- + "Heavy Combat Vessel Licence" permission
 }
 
 zpp.fctmod = {
