@@ -51,7 +51,7 @@ Converts a number of credits to a string.
       @return A string taking the form of "X ¤".
 --]]
 function format.credits( credits )
-   return n_("%s ¤", "%s ¤", credits):format(format.number(credits))
+   return n_("%s ¤", "%s ¤", math.abs(credits)):format(format.number(credits))
 end
 
 
@@ -61,7 +61,7 @@ Converts an item object or number of credits to reward string ("You have receive
    @usage vn.na(fmt.reward(money_reward))
 
       @param reward_list Thing or number of credits the player is receiving.
-                    Avoid passing strings (English or translated) for clarity's sake. Can be a table containing multiple instances.
+         Avoid passing strings (English or translated) for clarity's sake. Can be a table containing multiple instances.
       @return A string taking the form of "You have received X." -- translated and colourized.
 --]]
 function format.reward( reward_list )
@@ -94,7 +94,7 @@ Converts a number of tonnes to a string, using ngettext.
    @return A string taking the form of "X tonne" or "X tonnes".
 --]]
 function format.tonnes( tonnes )
-   return n_("%s tonne", "%s tonnes", tonnes):format(format.number(tonnes))
+   return n_("%s tonne", "%s tonnes", math.abs(tonnes)):format(format.number(tonnes))
 end
 
 
@@ -106,7 +106,7 @@ Like fmt.tonnes, but for abbreviations.
 --]]
 function format.tonnes_short( tonnes )
    -- Translator note: this form represents an abbreviation of "_ tonnes".
-   return n_( "%s t", "%s t", tonnes ):format(format.number(tonnes))
+   return n_( "%s t", "%s t", math.abs(tonnes)):format(format.number(tonnes))
 end
 
 
@@ -124,7 +124,7 @@ Converts a number of jumps to a string, utilizing ngettext.
       @return A string taking the form of "X jump" or "X jumps".
 --]]
 function format.jumps( jumps )
-   return n_("%s jump", "%s jumps", jumps):format(format.number(jumps))
+   return n_("%s jump", "%s jumps", math.abs(jumps)):format(format.number(jumps))
 end
 
 
@@ -146,19 +146,19 @@ function format.list( words )
    local length = #words
    if length == 1 then return tostring(words[1]) end
    if length == 2 then
-      return _replace(_replace( _("{0} and {1}"), '{0}', words[1]),
-         '{1}', words[2])
+      return _replace(_replace( _("{0} and {1}"), '{0}', tostring(words[1])),
+         '{1}', tostring(words[2]))
    end
 
-   local result = _replace( _("{0}, and {1}"), '{1}', words[length])
+   local result = _replace( _("{0}, and {1}"), '{1}', tostring(words[length]))
    while length > 3 do
       length = length - 1
-      local mid = _replace( _("{0}, {1}"), '{1}', words[length])
+      local mid = _replace( _("{0}, {1}"), '{1}', tostring(words[length]))
       result = _replace(result, '{0}', mid)
    end
-   result = _replace(result, '{0}', words[2])
+   result = _replace(result, '{0}', tostring(words[2]))
    result = _replace( _("{0}, {1}"), '{1}', result)
-   result = _replace(result, '{0}', words[1])
+   result = _replace(result, '{0}', tostring(words[1]))
    return result
 end
 
@@ -236,7 +236,7 @@ String interpolation, inspired by <a href="https://github.com/hishamhm/f-strings
    @usage fmt.f(_("A few digits of pi: {1:.2f}"), {math.pi})
 
    @tparam string str Format string which may include placeholders of the form "{var}" "{var:6.3f}"
-                      (where the expression after the colon is any directive string.format understands).
+      (where the expression after the colon is any directive string.format understands).
    @tparam table tab Argument table.
 --]]
 function format.f( str, tab )
